@@ -19,10 +19,10 @@ def to_lower_camel_case(x):
 
 
 def retain_filed_quotation(key, origin):
-    if isinstance(origin, str):
-        origin = f"'{origin}'"
-    elif key == "type":
-        origin = origin.__str__()
+    if isinstance(origin, str) and key != "foreign_keys":
+        origin = """%r""" % origin
+    elif key in ["type", "type_"]:
+        origin = """%r""" % origin
     return origin
 
 
@@ -31,4 +31,11 @@ def field_type_handle(field_type):
 
 
 def dict2params_str(source: dict):
-    return ','.join([f"{k}={retain_filed_quotation(k, v)}" for k, v in source.items()])
+    foreign_key_str = ""
+    if "foreign_keys" in source:
+        foreign_keys = source.pop("foreign_keys")
+        if foreign_keys:
+            for foreign_key in foreign_keys:
+                foreign_key_str += f'{foreign_key}, '
+    other_str = ', '.join([f"{k}={retain_filed_quotation(k, v)}" for k, v in source.items()])
+    return foreign_key_str + other_str
